"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const strategy_1 = require("./strategy");
/**
 * The parser that creates the AST of the input source code.
 *
 * @export
 * @class Parser
 */
class Parser {
    static walk() {
        const token = Parser.tokens[Parser.position];
        const strategy = Parser.strategies.find(s => s.supports(token));
        if (strategy) {
            const result = strategy.handle(Parser.tokens, Parser.position);
            Parser.position = (result.position || 0) + 1;
            return result.tokenOrExpression;
        }
        throw new TypeError(`Unknown Type: '${token.type}'. Value: '${token.value}'`);
    }
    static parse(tokens) {
        Parser.position = 0;
        Parser.tokens = tokens;
        const ast = {
            type: 'Program',
            tree: [],
        };
        while (Parser.position < tokens.length) {
            ast.tree.push(Parser.walk());
        }
        return ast;
    }
}
Parser.strategies = [
    new strategy_1.VariableDeclarationStrategy(),
    new strategy_1.ConsoleLogStrategy(),
    new strategy_1.CommentStrategy(),
];
Parser.position = 0;
Parser.tokens = [];
exports.Parser = Parser;
//# sourceMappingURL=parser.js.map