"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class CommentStrategy {
    /**
     * Checks whether this strategy supports the given `name`.
     *
     * @param {Token} token The name to check for.
     * @returns {boolean} Whether this strategy supports the given `name`.
     * @memberof CommentStrategy
     */
    supports(token) {
        if (!token || token === null) {
            return false;
        }
        return token.type === 'comment';
    }
    /**
     * Handle the `token`.
     *
     * @param {Token|Token[]} token The token to handle.
     * @param {number} [index] The index to start at.
     * @returns {ParserStrategyModel} The expression or the new token made from the `token`.
     * @throws {TypeError} Thrown when an error occurred while creating the expression.
     * @throws {SyntaxError} Thrown when the syntax is incorrect.
     * @throws {Error} Thrown when no index was provided.
     * @memberof CommentStrategy
     */
    handle(token, index) {
        const fragment = { type: 'Comment', value: '' };
        if (index === undefined) {
            throw new Error('No index provided.');
        }
        if (!Array.isArray(token)) {
            throw new Error('Non-Array provided.');
        }
        fragment.value = token[index].value;
        return {
            tokenOrExpression: fragment,
            position: index,
        };
    }
}
exports.CommentStrategy = CommentStrategy;
//# sourceMappingURL=comment-strategy.js.map