import { Token } from '@vongscript/common-interfaces';
import { ParserStrategy } from './parser-strategy';
import { ParserStrategyModel } from '../models';
/**
 * The startegy for console.log calls.
 *
 * @export
 * @class ConsoleLogStrategy
 * @implements {ParserStrategy}
 */
export declare class ConsoleLogStrategy implements ParserStrategy {
    /**
     * The strategies need by this strategy.
     *
     * @private
     * @type {ParserStrategy[]}
     * @memberof ConsoleLogStrategy
     */
    private strategies;
    /**
     * Checks whether this strategy supports the given `name`.
     *
     * @param {Token} token The name to check for.
     * @returns {boolean} Whether this strategy supports the given `name`.
     * @memberof ConsoleLogStrategy
     */
    supports(token: Token): boolean;
    /**
     * Handle the `token`.
     *
     * @param {Token|Token[]} token The token to handle.
     * @param {number} [index] The index to start at.
     * @returns {ParserStrategyModel} The expression or the new token made from the `token`.
     * @throws {TypeError} Thrown when an error occurred while creating the expression.
     * @throws {SyntaxError} Thrown when the syntax is incorrect.
     * @throws {Error} Thrown when no index was provided.
     * @memberof ConsoleLogStrategy
     */
    handle(token: Token | Token[], index?: number): ParserStrategyModel;
}
