"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * The strategy for boolean literals.
 *
 * @export
 * @class BooleanLiteralStrategy
 * @implements {ParserStrategy}
 */
class BooleanLiteralStrategy {
    /**
     * Checks whether this strategy supports the given `name`.
     *
     * @param {Token} token The name to check for.
     * @returns {boolean} Whether this strategy supports the given `name`.
     * @memberof BooleanLiteralStrategy
     */
    supports(token) {
        if (!token || token === null) {
            return false;
        }
        return token.type === 'boolean';
    }
    /**
     * Handle the `token`.
     *
     * @param {Token|Token[]} token The token to handle.
     * @returns {ParserStrategyModel} The expression or the new token made from the `token`.
     * @throws {Error} Thrown when an array instead of a single token was provided.
     * @memberof BooleanLiteralStrategy
     */
    handle(token) {
        if (!Array.isArray(token)) {
            return {
                tokenOrExpression: { type: 'BooleanLiteral', value: token.value },
            };
        }
        throw new Error('Array provided but single token expected.');
    }
}
exports.BooleanLiteralStrategy = BooleanLiteralStrategy;
//# sourceMappingURL=boolean-literal-strategy.js.map