"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * The strategy for number literals.
 *
 * @export
 * @class NumberLiteralStrategy
 * @implements {ParserStrategy}
 */
class NumberLiteralStrategy {
    /**
     * Checks whether this strategy supports the given `name`.
     *
     * @param {Token} token The name to check for.
     * @returns {boolean} Whether this strategy supports the given `name`.
     * @memberof NumberLiteralStrategy
     */
    supports(token) {
        if (!token || token === null) {
            return false;
        }
        return token.type === 'number';
    }
    /**
     * Handle the `token`.
     *
     * @param {Token|Token[]} token The token to handle.
     * @returns {ParserStrategyModel} The expression or the new token made from the `token`.
     * @throws {Error} Thrown when an array instead of a single token was provided.
     * @memberof ParserStrategy
     */
    handle(token) {
        if (!Array.isArray(token)) {
            return {
                tokenOrExpression: { type: 'NumberLiteral', value: token.value },
            };
        }
        throw new Error('Array provided but single token expected.');
    }
}
exports.NumberLiteralStrategy = NumberLiteralStrategy;
//# sourceMappingURL=number-literal-strategy.js.map