import { Token } from '@vongscript/common-interfaces';
import { ParserStrategyModel } from '../models';
/**
 * The abstract class for the parser strategies.
 *
 * @export
 * @interface ParserStrategy
 */
export interface ParserStrategy {
    /**
     * Checks whether this strategy supports the given `token`.
     *
     * @param {Token} token The token to check for.
     * @returns {boolean} Whether this strategy supports the given `token`.
     * @memberof ParserStrategy
     */
    supports(token: Token): boolean;
    /**
     * Handle the `token`.
     *
     * @param {Token|Token[]} token The token to handle.
     * @param {number} [index] The index to start at.
     * @returns {ParserStrategyModel} The expression or the new token made from the `token`.
     * @throws {TypeError} Thrown when an error occurred while creating the expression.
     * @throws {SyntaxError} Thrown when the syntax is incorrect.
     * @memberof ParserStrategy
     */
    handle(token: Token | Token[], index?: number): ParserStrategyModel;
}
