"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const literals_1 = require("./literals");
class VariableDeclarationStrategy {
    constructor() {
        this.strategies = [
            new literals_1.StringLiteralStrategy(),
            new literals_1.NumberLiteralStrategy(),
            new literals_1.BooleanLiteralStrategy(),
        ];
    }
    /**
     * Checks whether this strategy supports the given `name`.
     *
     * @param {Token} token The name to check for.
     * @returns {boolean} Whether this strategy supports the given `name`.
     * @memberof VariableDeclarationStrategy
     */
    supports(token) {
        if (!token || token === null) {
            return false;
        }
        return token.value === 'iBims';
    }
    /**
     * Handle the `token`.
     *
     * @param {Token|Token[]} token The token to handle.
     * @param {number} [index] The index to start at.
     * @returns {ParserStrategyModel} The expression or the new token made from the `token`.
     * @throws {TypeError} Thrown when an error occurred while creating the expression.
     * @throws {SyntaxError} Thrown when the syntax is incorrect.
     * @throws {Error} Thrown when no index was provided.
     * @memberof VariableDeclarationStrategy
     */
    handle(token, index) {
        const fragment = { type: 'VariableDeclaration', params: [] };
        if (index === undefined) {
            throw new Error('No index provided.');
        }
        if (!Array.isArray(token)) {
            throw new Error('Non-Array provided.');
        }
        index++;
        fragment.params.push({ type: 'Identifier', value: token[index].value });
        index++;
        if (token[index].value === 'vongValueHer') {
            index++;
            const t = token[index];
            const strategy = this.strategies.find(s => s.supports(t));
            if (strategy) {
                fragment.params.push(strategy.handle(token[index])
                    .tokenOrExpression);
            }
            else {
                throw new TypeError('Trying to assign unknown type.');
            }
            return { tokenOrExpression: fragment, position: index };
        }
        throw new SyntaxError("Invalid variable assignment. Keyword 'vongValueHer' is missing.");
    }
}
exports.VariableDeclarationStrategy = VariableDeclarationStrategy;
//# sourceMappingURL=variable-declaration-strategy.js.map